Package org.cloudsimplus.utilizationmodels


package org.cloudsimplus.utilizationmodels

Provides classes that model utilization of resources such as Pe (CPU), Ram and Bandwidth, defining how a given resource is used by a Cloudlet along the simulation time.

The most basic utilization model that can be used for any of the mentioned resources is the UtilizationModelFull, which may not be realistic for most of the scenarios. This way, other implementations such as UtilizationModelDynamic might be more suitable.

Author:
Manoel Campos da Silva Filho