Package org.cloudsimplus.utilizationmodels
package org.cloudsimplus.utilizationmodels
Provides classes that model utilization of resources such as
Pe (CPU), Ram and
Bandwidth,
defining how a given resource is used by a Cloudlet
along the simulation time.
The most basic utilization model that can be used for any of the mentioned resources
is the UtilizationModelFull, which may not be realistic
for most of the scenarios.
This way, other implementations such as UtilizationModelDynamic
might be more suitable.
- Author:
- Manoel Campos da Silva Filho
-
ClassDescriptionDefines how a
Machineuses resources such as CPU and RAM during the boot process.An interface to be implemented to provide a fine-grained control over resource usage by aCloudlet.Defines the unit of the resource utilization.An abstract class to implementUtilizationModels.ACloudletUtilizationModelthat allows to increase the utilization of the related resource along the simulation time.AUtilizationModelthat makes a Cloudlet always utilize a given allocated resource from its Vm at 100%, all the time.Implements a model, according to which aCloudletgenerates random resource utilization every time frame, using aContinuousDistribution.